/*
 * Copyright 2011 Canonical Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier@tilloy.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1

GridView {
    property int headerHeight: 28
    property string headerText

    height: headerHeight + delegateHeight * lines

    SystemPalette {
        id: activePalette
        colorGroup: SystemPalette.Active
    }

    header: Item {
        anchors.left: parent.left
        anchors.right: parent.right
        height: parent.parent.headerHeight

        Rectangle {
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            height: 1
            color: activePalette.mid
        }

        Text {
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            anchors.leftMargin: 10
            font.pointSize: 11
            font.bold: true
            color: activePalette.windowText
            text: parent.parent.parent.headerText
        }
    }

    property int delegateMinHeight: 85
    property int delegateMaxHeight: 107
    property int delegateMinWidth: 186
    property int delegateMaxWidth: 223

    property int columns: Math.floor((width / delegateMinWidth + width / delegateMaxWidth) / 2)
    property int lines: Math.floor(count / columns) + (((count % columns) > 0) ? 1 : 0)

    property int delegateWidth: Math.floor(width / columns)
    property int delegateHeight: (lines == 1) ? delegateMaxHeight : delegateMinHeight
    cellWidth: delegateWidth
    cellHeight: delegateHeight

    delegate: Item {
        height: GridView.view.delegateHeight
        width: GridView.view.delegateWidth

        property bool lastLine: index >= (GridView.view.lines - 1) * GridView.view.columns
        property bool firstColumn: index % GridView.view.columns == 0
        property bool lastColumn: (index + 1) % GridView.view.columns == 0

        MouseArea {
            id: mousearea
            anchors.fill: parent
            hoverEnabled: true
            onClicked: console.log("Open item", index, "in category", parent.GridView.view.headerText)
        }

        // FIXME: This doesn’t respect encapsulation as it implies that we
        //        know that the grid is inside a rounded-corner frame.
        OneRoundedCornerRectangle {
            anchors.fill: parent
            corner: {
                if (parent.lastLine && parent.firstColumn) return Qt.BottomLeftCorner
                if (parent.lastLine && parent.lastColumn) return Qt.BottomRightCorner
                // unused, but we need to return a valid value anyway
                return Qt.TopLeftCorner
            }
            radius: (parent.lastLine && (parent.firstColumn || parent.lastColumn)) ? 8 : 0
            color: activePalette.midlight
            opacity: mousearea.containsMouse ? 1.0 : 0.0
        }

        Rectangle {
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            height: 1
            color: activePalette.mid
            visible: !parent.lastLine
        }

        Rectangle {
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            width: 1
            color: activePalette.mid
            visible: !parent.lastColumn
        }

        Row {
            anchors.fill: parent
            anchors.margins: 5
            spacing: 5

            Image {
                source: "../../../data/icons/48x48/apps/softwarecenter.svg"
            }

            Column {
                spacing: 3

                Text {
                    height: 15
                    font.pointSize: 10
                    font.bold: true
                    color: activePalette.windowText
                    text: "Application Title"
                }

                Text {
                    height: 15
                    font.pointSize: 10
                    color: activePalette.windowText
                    text: "Category"
                }

                Row {
                    spacing: 8

                    Stars {
                        height: 16
                        ratings_average: 3.5
                    }

                    Text {
                        height: 16
                        font.pointSize: 9
                        color: activePalette.mid
                        text: "(%1)".arg("n")
                    }
                }

                Text {
                    height: 15
                    font.pointSize: 10
                    color: activePalette.mid
                    text: "$$$"
                }
            }
        }
    }
}

