/*
 * Copyright 2011 Canonical Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier@tilloy.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1

Item {
    id: rectangle
    property int corner: Qt.TopLeftCorner
    property real radius: 0.0
    property color color

    Item {
        anchors.fill: parent
        clip: true
        Rectangle {
            // rounded corner
            property alias corner: rectangle.corner

            radius: rectangle.radius

            width: radius * 2
            height: radius * 2

            x: {
                if ((corner == Qt.TopLeftCorner) || (corner == Qt.BottomLeftCorner)) return 0
                if ((corner == Qt.TopRightCorner) || (corner == Qt.BottomRightCorner)) return (parent.width - 2 * radius)
            }
            y: {
                if ((corner == Qt.TopLeftCorner) || (corner == Qt.TopRightCorner)) return 0
                if ((corner == Qt.BottomLeftCorner) || (corner == Qt.BottomRightCorner)) return (parent.height - 2 * radius)
            }

            color: rectangle.color
        }
    }

    Rectangle {
        // vertical edge
        property alias corner: rectangle.corner

        width: rectangle.radius
        height: parent.height - rectangle.radius

        x: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.BottomLeftCorner)) return 0
            if ((corner == Qt.TopRightCorner) || (corner == Qt.BottomRightCorner)) return (parent.width - width)
        }
        y: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.TopRightCorner)) return width
            if ((corner == Qt.BottomLeftCorner) || (corner == Qt.BottomRightCorner)) return 0
        }

        color: parent.color
    }

    Rectangle {
        // horizontal edge
        property alias corner: rectangle.corner

        width: parent.width - rectangle.radius
        height: rectangle.radius

        x: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.BottomLeftCorner)) return height
            if ((corner == Qt.TopRightCorner) || (corner == Qt.BottomRightCorner)) return 0
        }
        y: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.TopRightCorner)) return 0
            if ((corner == Qt.BottomLeftCorner) || (corner == Qt.BottomRightCorner)) return (parent.height - height)
        }

        color: parent.color
    }

    Rectangle {
        // center
        property alias corner: rectangle.corner

        width: parent.width - rectangle.radius
        height: parent.height - rectangle.radius

        x: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.BottomLeftCorner)) return rectangle.radius
            if ((corner == Qt.TopRightCorner) || (corner == Qt.BottomRightCorner)) return 0
        }
        y: {
            if ((corner == Qt.TopLeftCorner) || (corner == Qt.TopRightCorner)) return rectangle.radius
            if ((corner == Qt.BottomLeftCorner) || (corner == Qt.BottomRightCorner)) return 0
        }

        color: parent.color
    }
}

