/*
 * Copyright 2011 Canonical Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier@tilloy.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1

FocusScope {
    width: 835
    height: 600
    focus: true

    SystemPalette {
        id: activePalette
        colorGroup: SystemPalette.Active
    }

    Rectangle {
        id: toolbar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        height: 66
        color: activePalette.buttonText

        SearchBox {
            id: searchbox
            anchors.right: parent.right
            anchors.rightMargin: 16
            anchors.verticalCenter: parent.verticalCenter
            width: 267
        }
    }

    Flickable {
        id: contents
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: toolbar.bottom
        anchors.bottom: parent.bottom
        contentWidth: width
        contentHeight: header.height + categories.height + statustext.height + 20
        clip: true
        boundsBehavior: Flickable.StopAtBounds

        Image {
            id: header
            anchors.left: parent.left
            anchors.top: parent.top
            height: 200
            width: 835
            source: "../../../data/default_banner/fallback.png"

            Text {
                x: 230
                y: 50
                text: "Our star apps"
                font.pointSize: 36
                font.bold: true
            }

            Text {
                x: 230
                y: 110
                text: "Come and explore our favourites"
                font.pointSize: 21
            }
        }

        Image {
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: header.bottom
            source: "../../../data/ui/gtk3/art/exhibit-dropshadow-s.png"
            fillMode: Image.TileHorizontally
        }

        Image {
            anchors.top: header.bottom
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            fillMode: Image.Tile
            opacity: 0.5
            source: "../../../data/ui/gtk3/art/stipple.png"
        }

        Frame2 {
            id: categories
            width: categoriesview.width
            anchors.margins: 10
            anchors.left: parent.left
            anchors.top: header.bottom
            height: toprated.y + toprated.height - y
            color: "#f0efee"

            ListView {
                id: categoriesview
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                width: 0
                anchors.margins: 5
                anchors.leftMargin: 11
                model: categoriesmodel
                interactive: false
                delegate: Text {
                    text: _name
                    height: 27
                    width: paintedWidth
                    font.pointSize: 9
                    color: activePalette.text
                    MouseArea {
                        anchors.fill: parent
                        onClicked: console.log("Open category", parent.text)
                    }
                    Component.onCompleted: {
                        var w = width + 23
                        if (categoriesview.width < w) {
                            categoriesview.width = w
                        }
                    }
                }
            }
        }

        Frame2 {
            id: whatsnew
            anchors.margins: 10
            anchors.left: categories.right
            anchors.right: parent.right
            anchors.top: header.bottom
            height: whatsnewview.height + 2
            color: "#f0efee"

            HomeGrid {
                id: whatsnewview

                anchors.left: parent.left
                anchors.leftMargin: 1
                anchors.right: parent.right
                anchors.top: parent.top

                interactive: false

                headerText: "What’s New"

                model: [0,1,2,3,4,5,6,7]
            }
        }

        Frame2 {
            id: toprated
            anchors.margins: 10
            anchors.left: categories.right
            anchors.right: parent.right
            anchors.top: whatsnew.bottom
            height: topratedview.height + 2
            color: "#f0efee"

            HomeGrid {
                id: topratedview

                anchors.left: parent.left
                anchors.leftMargin: 1
                anchors.right: parent.right
                anchors.top: parent.top

                interactive: false

                headerText: "Top Rated"

                model: [0,1,2,3,4,5,6,7,8,9,10,11]
            }
        }

        Text {
            id: statustext
            anchors.top: toprated.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.margins: 5
            height: paintedHeight
            horizontalAlignment: Text.AlignHCenter
            color: activePalette.text
            //text: "%1 items".arg(applicationsmodel.rowCount())
        }
    }

    ScrollBar {
        id: scrollbar
        width: 4
        orientation: Qt.Vertical
        anchors.right: contents.right
        anchors.top: contents.top
        anchors.bottom: contents.bottom
        position: contents.visibleArea.yPosition
        pageSize: contents.visibleArea.heightRatio
        visible: true
        clip: true
    }
}

